/*
***********************************************************************************************
*						SHT1x digital temperature and humidity sensor Driver
*										All Rights Reserved
* File name		: SHT1x.c
* Programmer 	: John Leung, TechToys Co. Hong Kong
* Web presence  : www.TechToys.com.hk
* Note			: 
* Language		: C18 complier version 2.40, MPLAB v7.41
* Hardware		: PIC18LF4550-STK1
* Date			: 11 Oct 2006			Version 1.0 

***********************************************************************************************
*										DESCRIPTION
*
* This module provides an interface to Sensirion SHT10 digital temperature & humidity sensor
*
* pinout function summarized as below
* ---SHT1x			MCU -----------------
* DATA - data		RA2
* SCK  - clock		RA0
***********************************************************************************************
*/

/*
***********************************************************************************************
* Date 24th Apr 2008
* Defines DelayUs(x) in this file for DelayUs()
***********************************************************************************************
*/
#ifndef SHT1X_H
#define SHT1X_H

/*
***********************************************************************************************
*										PORT DEFINITION
***********************************************************************************************
*/
#define DATA_WR		LATAbits.LATA2
#define	DATA_RD   	PORTAbits.RA2
#define	SCK   		LATAbits.LATA0
#define DATA_TRIS	TRISAbits.TRISA2
#define SCK_TRIS	TRISAbits.TRISA0

/*
***********************************************************************************************
*										GLOBAL CONSTANTS
***********************************************************************************************
*/

enum {TEMP,HUMI};	

/*
***********************************************************************************************
*									FUNCTION PROTOTYPES
***********************************************************************************************
*/
char s_softreset(void);
char s_measure(unsigned char *p_value, unsigned char *p_checksum, unsigned char mode);
char s_write_statusreg(unsigned char *p_value);
char s_read_statusreg(unsigned char *p_value, unsigned char *p_checksum);
/*
***********************************************************************************************
*									FUNCTION PROTOTYPES
*									 HARDWARE SPECIFIC
***********************************************************************************************
*/

void s_transstart(void);
void s_connectionreset(void);
char s_read_byte(unsigned char ack);
char s_write_byte(unsigned char value);

/*
***********************************************************************************************
*									DelayUs function defined here
***********************************************************************************************
*/
//SYSCLK defined under includes.h as system information
#define XTAL_FREQ (SYSCLK*4)/1000	//freq in MHz

#ifndef	XTAL_FREQ
#define	XTAL_FREQ	48MHZ		/* Crystal frequency in MHz */
#endif

#define	MHZ	*1000L			/* number of kHz in a MHz */
#define	KHZ	*1				/* number of kHz in a kHz */

#if	XTAL_FREQ >= 12MHZ

#define	DelayUs(x)	{ unsigned char _dcnt; \
			  _dcnt = (x)*((XTAL_FREQ)/(12MHZ)); \
			  while(--_dcnt != 0) \
				  continue; }
#else

#define	DelayUs(x)	{ unsigned char _dcnt; \
			  _dcnt = (x)/((12MHZ)/(XTAL_FREQ))|1; \
			  while(--_dcnt != 0) \
				  continue; }
#endif